<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>すべてのファイル (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authenticating</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>機内モード</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>無線通信を停止します</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>機内モードを有効化すると、ワイヤレスネットワーク、ホットスポット、BluetoothがすべてOFFになります</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>アプリケーションプロキシ</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>プロキシサーバーをセットアップ</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>プロキシタイプ</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IPアドレス</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>IPアドレスが無効です</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>ポートが無効です</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>任意</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>構成が完了したら、ランチャーのアプリケーションコンテキストで&quot;プロキシを使用する&quot;を選択してください</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>ダイヤルアップ接続をセットアップ</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>PPPoE接続を追加</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>この構成を削除してもよろしいですか？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>ネットワークの詳細</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>すべてのネットワーク構成を表示</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>詳細がコピーされました</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>すべて選択</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>ネットワーク検出</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>バインドされていません</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>パーソナルホットスポット</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>ネットワークを共有</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>マイホットスポット</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>マイホットスポットを編集</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>名前(SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>バンド</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>共有設定</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>ホットスポットを共有するデバイス</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>パーソナルホットスポットを使用するには、機内モードを無効化してからワイヤレスネットワークアダプターを有効化してください。</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>パーソナルホットスポットを使用するには、&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;機内モード&lt;/a&gt;を無効化してからワイヤレスネットワークアダプターを有効化してください。</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>この構成を削除してもよろしいですか？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>システムプロキシ</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>プロキシサーバーをセットアップ</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>プロキシタイプ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>設定 URL</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP プロキシ</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS プロキシ</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP プロキシ</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS プロキシ</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>上記のホストとドメインでプロキシ設定を無視</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>接続、追加、インポート</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>VPNを追加</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPNをインポート</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>インポートエラー</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>ファイルエラー</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>VPN の種類</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>この構成を削除してもよろしいですか？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>接続、ネットワーク設定の編集</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>まずネットワークケーブルを接続してください</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>ネットワーク接続を追加</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>接続、ネットワーク設定の編集</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>その他のネットワーク</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>ワイヤレスネットワーク接続を行うには機内モードを無効化してください</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>ワイヤレスネットワークに接続するには、&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;機内モード&lt;/a&gt;を無効化してください。</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>ワイヤレスネットワーク接続を行うにはホットスポットを無効化してください</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>ワイヤレスネットワークに接続するには、&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;ホットスポット&lt;/a&gt;を無効化してください。</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>IPアドレスが無効です</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>バインドされていません</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>無線LAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>イーサーネット</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>デバイスの MAC アドレス</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>複製 MAC アドレス</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU をカスタマイズ</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>バンド</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>名前(SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>自動接続</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>無効化</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>メソッド</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>一致するリソースにのみ適用されます</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IPアドレス</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>IPアドレスが無効です</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ネットマスク</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無効なネットマスクです</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>IPアドレスが重複しています</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>無効化</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>無視</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>メソッド</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>一致するリソースにのみ適用されます</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IPアドレス</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>IPアドレスが無効です</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>プレフィックス</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無効なネットマスクです</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>IPアドレスが重複しています</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE を使う</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128 ビット MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 認証を拒否</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD データを圧縮しない</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>デフレートデータを圧縮しない</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP ヘッダーを圧縮しない</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP エコーパケットを送る</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>サービス</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>トンネル TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>保護された EAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP 認証</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>アイデンティティ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>パスワードのオプション</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>このユーザーのパスワードを保存する</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>全ユーザーのパスワードを保存する</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>常に確認する</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>キー</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>プライベートパスワード</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>認証</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>共有キー</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>システムを開く</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>プライベートキー</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>匿名 ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>プロビジョニング</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>無効化</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>匿名</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>認証済み</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>両方</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC ファイル</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 証明書</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ユーザー証明書</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP バージョン</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>バージョン 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>バージョン 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner 認証</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>すべてのファイル (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無効なゲートウェイです</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 証明書</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>プロキシ</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco Secure Desktop トロイを許可</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD スクリプト</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>認証の種類</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>プライベートキー</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH エージェント</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>スマートカード</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>事前共有キー</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ユーザー証明書</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>キーパスフレーズに FSID を使用</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>証明書 (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>証明書パスワード(TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>静的キー</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>パスワードのオプション</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>保存済み</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>確認する</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>省略可</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>プライベートパスワード</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>キーの方向をカスタマイズ</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>キーの方向</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>リモート IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>ローカル IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT ドメイン</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>内部 IP アドレスを要求</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP カプセル化を強制</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP 圧縮を使用</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>カスタム暗号提案を有効にする</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>グループ名</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>グループパスワード</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>ハイブリッド認証を使用</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA ファイル</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE を使う</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>すべて有効 (デフォルト)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 ビット (低セキュリティ)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 ビット (高セキュリティ)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP 認証を拒否</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 認証を拒否</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD データを圧縮しない</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>デフレートデータを圧縮しない</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP ヘッダーを圧縮しない</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>プロトコルフィールドを圧縮しない</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>アドレス／コントロールを圧縮しない</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP エコーパケットを送る</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation> IPsec の有効</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>グループ ID</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>フェーズ1アルゴリズム</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>フェーズ2アルゴリズム</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>高度な VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>ゲートウェイポートのカスタマイズ</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>ゲートウェイポート</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>認識間隔のカスタマイズ</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>認識間隔</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO データ圧縮を使う</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP 接続を使う</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP デバイスを使う</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>トンネル MTU のカスタマイズ</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP フラグメントサイズのカスタマイズ</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP フラグメントのサイズ</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Tunnel TCP MSS の禁止</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>リモートホストをランダムにする</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>ドメイン</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>ベンダー</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (デフォルト)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>ネットスクリーン</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>暗号化</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>安全 (デフォルト)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>弱</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NATトラバースモード</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>可能時は NAT-T (デフォルト)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>常に NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>無効化</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH グループ</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH グループ 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH グループ 2 (デフォルト)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH グループ 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>前方秘匿性</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>サーバー (デフォルト)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH グループ 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>ローカルポート</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>デッドピア検知を無効化</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>VPN セキュリティ</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC 認証</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN プロキシ</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>プロキシタイプ</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>サーバー IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>失敗時に再試行</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS 認証</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>サブジェクトマッチ</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>リモート証明書の種類</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>クライアント</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>サーバー</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>キーファイル</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>任意</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>認証が必要です</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必須</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>ワイヤレスネットワークに接続するには、&lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;機内モード&lt;/a&gt;を無効化してください。</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP競合</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>有線接続 %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE 接続 %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>&quot;%1&quot; に接続中</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; 接続にされました</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; から切断されました</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>&quot;%1&quot; に接続できませんでした。ルーターやケーブルを確認してください。</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>&quot;%1&quot; に接続できませんでした。もっとワイヤレスルーターに近づいてください。</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>接続失敗、&quot;%1&quot; に接続できませんでした。パスワードが間違っています。</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>&quot;%1&quot; に接続するには、パスワードが必要です。</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>&quot;%1&quot; 802.11 無線LANネットワークが見つかりませんでした。</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>&quot;%1&quot; に接続するには、ログイン後に認証鵜情報を構成する必要があります。</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>システムプロキシ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>VPN構成が接続されていないか、接続に失敗しました。&lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;コントロールセンターで確認&lt;/a&gt;してください。</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>非表示のネットワークへ接続</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>マイ ネットワーク</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>その他のネットワーク</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>